@@ -6,6 +6,7 @@ from __future__ import print_function
 import sys
 import textwrap
 
+import attr
 import py
 import six
 
@@ -487,6 +488,30 @@ class TestAssert_reprcompare(object):
         expl = callequal([(1, 2)], [])
         assert len(expl) > 1
 
+    def test_repr_verbose(self):
+        class Nums:
+            def __init__(self, nums):
+                self.nums = nums
+
+            def __repr__(self):
+                return str(self.nums)
+
+        list_x = list(range(5000))
+        list_y = list(range(5000))
+        list_y[len(list_y) // 2] = 3
+        nums_x = Nums(list_x)
+        nums_y = Nums(list_y)
+
+        assert callequal(nums_x, nums_y) is None
+
+        expl = callequal(nums_x, nums_y, verbose=1)
+        assert "-" + repr(nums_x) in expl
+        assert "+" + repr(nums_y) in expl
+
+        expl = callequal(nums_x, nums_y, verbose=2)
+        assert "-" + repr(nums_x) in expl
+        assert "+" + repr(nums_y) in expl
+
     def test_list_bad_repr(self):
         class A(object):
             def __repr__(self):
@@ -549,6 +574,115 @@ class TestAssert_reprcompare(object):
         assert msg
 
 
+class TestAssert_reprcompare_dataclass(object):
+    @pytest.mark.skipif(sys.version_info < (3, 7), reason="Dataclasses in Python3.7+")
+    def test_dataclasses(self, testdir):
+        p = testdir.copy_example("dataclasses/test_compare_dataclasses.py")
+        result = testdir.runpytest(p)
+        result.assert_outcomes(failed=1, passed=0)
+        result.stdout.fnmatch_lines(
+            [
+                "*Omitting 1 identical items, use -vv to show*",
+                "*Differing attributes:*",
+                "*field_b: 'b' != 'c'*",
+            ]
+        )
+
+    @pytest.mark.skipif(sys.version_info < (3, 7), reason="Dataclasses in Python3.7+")
+    def test_dataclasses_verbose(self, testdir):
+        p = testdir.copy_example("dataclasses/test_compare_dataclasses_verbose.py")
+        result = testdir.runpytest(p, "-vv")
+        result.assert_outcomes(failed=1, passed=0)
+        result.stdout.fnmatch_lines(
+            [
+                "*Matching attributes:*",
+                "*['field_a']*",
+                "*Differing attributes:*",
+                "*field_b: 'b' != 'c'*",
+            ]
+        )
+
+    @pytest.mark.skipif(sys.version_info < (3, 7), reason="Dataclasses in Python3.7+")
+    def test_dataclasses_with_attribute_comparison_off(self, testdir):
+        p = testdir.copy_example(
+            "dataclasses/test_compare_dataclasses_field_comparison_off.py"
+        )
+        result = testdir.runpytest(p, "-vv")
+        result.assert_outcomes(failed=0, passed=1)
+
+    @pytest.mark.skipif(sys.version_info < (3, 7), reason="Dataclasses in Python3.7+")
+    def test_comparing_two_different_data_classes(self, testdir):
+        p = testdir.copy_example(
+            "dataclasses/test_compare_two_different_dataclasses.py"
+        )
+        result = testdir.runpytest(p, "-vv")
+        result.assert_outcomes(failed=0, passed=1)
+
+
+class TestAssert_reprcompare_attrsclass(object):
+    def test_attrs(self):
+        @attr.s
+        class SimpleDataObject(object):
+            field_a = attr.ib()
+            field_b = attr.ib()
+
+        left = SimpleDataObject(1, "b")
+        right = SimpleDataObject(1, "c")
+
+        lines = callequal(left, right)
+        assert lines[1].startswith("Omitting 1 identical item")
+        assert "Matching attributes" not in lines
+        for line in lines[1:]:
+            assert "field_a" not in line
+
+    def test_attrs_verbose(self):
+        @attr.s
+        class SimpleDataObject(object):
+            field_a = attr.ib()
+            field_b = attr.ib()
+
+        left = SimpleDataObject(1, "b")
+        right = SimpleDataObject(1, "c")
+
+        lines = callequal(left, right, verbose=2)
+        assert lines[1].startswith("Matching attributes:")
+        assert "Omitting" not in lines[1]
+        assert lines[2] == "['field_a']"
+
+    def test_attrs_with_attribute_comparison_off(self):
+        @attr.s
+        class SimpleDataObject(object):
+            field_a = attr.ib()
+            field_b = attr.ib(cmp=False)
+
+        left = SimpleDataObject(1, "b")
+        right = SimpleDataObject(1, "b")
+
+        lines = callequal(left, right, verbose=2)
+        assert lines[1].startswith("Matching attributes:")
+        assert "Omitting" not in lines[1]
+        assert lines[2] == "['field_a']"
+        for line in lines[2:]:
+            assert "field_b" not in line
+
+    def test_comparing_two_different_attrs_classes(self):
+        @attr.s
+        class SimpleDataObjectOne(object):
+            field_a = attr.ib()
+            field_b = attr.ib()
+
+        @attr.s
+        class SimpleDataObjectTwo(object):
+            field_a = attr.ib()
+            field_b = attr.ib()
+
+        left = SimpleDataObjectOne(1, "b")
+        right = SimpleDataObjectTwo(1, "c")
+
+        lines = callequal(left, right)
+        assert lines is None
+
+
 class TestFormatExplanation(object):
     def test_special_chars_full(self, testdir):
         # Issue 453, for the bug this would raise IndexError
