@@ -20,7 +20,6 @@ from _pytest.terminal import build_summary_stats_line
 from _pytest.terminal import getreportopt
 from _pytest.terminal import repr_pythonversion
 from _pytest.terminal import TerminalReporter
-from _pytest.warnings import SHOW_PYTEST_WARNINGS_ARG
 
 DistInfo = collections.namedtuple("DistInfo", ["project_name", "version"])
 
@@ -105,7 +104,8 @@ class TestTerminal(object):
     def test_internalerror(self, testdir, linecomp):
         modcol = testdir.getmodulecol("def test_one(): pass")
         rep = TerminalReporter(modcol.config, file=linecomp.stringio)
-        excinfo = pytest.raises(ValueError, "raise ValueError('hello')")
+        with pytest.raises(ValueError) as excinfo:
+            raise ValueError("hello")
         rep.pytest_internalerror(excinfo.getrepr())
         linecomp.assert_contains_lines(["INTERNALERROR> *ValueError*hello*"])
 
@@ -263,7 +263,7 @@ class TestCollectonly(object):
         )
         result = testdir.runpytest("--collect-only")
         result.stdout.fnmatch_lines(
-            ["<Module 'test_collectonly_basic.py'>", "  <Function 'test_func'>"]
+            ["<Module test_collectonly_basic.py>", "  <Function test_func>"]
         )
 
     def test_collectonly_skipped_module(self, testdir):
@@ -276,6 +276,18 @@ class TestCollectonly(object):
         result = testdir.runpytest("--collect-only", "-rs")
         result.stdout.fnmatch_lines(["*ERROR collecting*"])
 
+    def test_collectonly_display_test_description(self, testdir):
+        testdir.makepyfile(
+            """
+            def test_with_description():
+                \""" This test has a description.
+                \"""
+                assert True
+        """
+        )
+        result = testdir.runpytest("--collect-only", "--verbose")
+        result.stdout.fnmatch_lines(["    This test has a description."])
+
     def test_collectonly_failed_module(self, testdir):
         testdir.makepyfile("""raise ValueError(0)""")
         result = testdir.runpytest("--collect-only")
@@ -307,11 +319,10 @@ class TestCollectonly(object):
         assert result.ret == 0
         result.stdout.fnmatch_lines(
             [
-                "*<Module '*.py'>",
-                "* <Function 'test_func1'*>",
-                "* <Class 'TestClass'>",
-                # "*  <Instance '()'>",
-                "*   <Function 'test_method'*>",
+                "*<Module *.py>",
+                "* <Function test_func1>",
+                "* <Class TestClass>",
+                "*   <Function test_method>",
             ]
         )
 
@@ -540,7 +551,7 @@ class TestTerminalFunctional(object):
         result.stdout.fnmatch_lines(["test_passes.py ..*", "* 2 pass*"])
         assert result.ret == 0
 
-    def test_header_trailer_info(self, testdir):
+    def test_header_trailer_info(self, testdir, request):
         testdir.makepyfile(
             """
             def test_passes():
@@ -564,7 +575,7 @@ class TestTerminalFunctional(object):
                 "=* 1 passed*in *.[0-9][0-9] seconds *=",
             ]
         )
-        if pytest.config.pluginmanager.list_plugin_distinfo():
+        if request.config.pluginmanager.list_plugin_distinfo():
             result.stdout.fnmatch_lines(["plugins: *"])
 
     def test_showlocals(self, testdir):
@@ -585,8 +596,9 @@ class TestTerminalFunctional(object):
             ]
         )
 
-    def test_verbose_reporting(self, testdir, pytestconfig):
-        p1 = testdir.makepyfile(
+    @pytest.fixture
+    def verbose_testfile(self, testdir):
+        return testdir.makepyfile(
             """
             import pytest
             def test_fail():
@@ -602,22 +614,32 @@ class TestTerminalFunctional(object):
                 yield check, 0
         """
         )
-        result = testdir.runpytest(p1, "-v", SHOW_PYTEST_WARNINGS_ARG)
+
+    def test_verbose_reporting(self, verbose_testfile, testdir, pytestconfig):
+
+        result = testdir.runpytest(
+            verbose_testfile, "-v", "-Walways::pytest.PytestWarning"
+        )
         result.stdout.fnmatch_lines(
             [
                 "*test_verbose_reporting.py::test_fail *FAIL*",
                 "*test_verbose_reporting.py::test_pass *PASS*",
                 "*test_verbose_reporting.py::TestClass::test_skip *SKIP*",
-                "*test_verbose_reporting.py::test_gen*0* *FAIL*",
+                "*test_verbose_reporting.py::test_gen *xfail*",
             ]
         )
         assert result.ret == 1
 
+    def test_verbose_reporting_xdist(self, verbose_testfile, testdir, pytestconfig):
         if not pytestconfig.pluginmanager.get_plugin("xdist"):
             pytest.skip("xdist plugin not installed")
 
-        result = testdir.runpytest(p1, "-v", "-n 1", SHOW_PYTEST_WARNINGS_ARG)
-        result.stdout.fnmatch_lines(["*FAIL*test_verbose_reporting.py::test_fail*"])
+        result = testdir.runpytest(
+            verbose_testfile, "-v", "-n 1", "-Walways::pytest.PytestWarning"
+        )
+        result.stdout.fnmatch_lines(
+            ["*FAIL*test_verbose_reporting_xdist.py::test_fail*"]
+        )
         assert result.ret == 1
 
     def test_quiet_reporting(self, testdir):
